@@ -88,13 +88,13 @@ class Col : public Mat<eT>
   inline            Col(const subview_cube<eT>& X);
   inline Col& operator=(const subview_cube<eT>& X);
   
-  arma_deprecated inline mat_injector<Col> operator<<(const eT val);
+  arma_frown("use braced initialiser list instead") inline mat_injector<Col> operator<<(const eT val);
   
-  arma_inline arma_warn_unused const Op<Col<eT>,op_htrans>  t() const;
-  arma_inline arma_warn_unused const Op<Col<eT>,op_htrans> ht() const;
-  arma_inline arma_warn_unused const Op<Col<eT>,op_strans> st() const;
+  arma_warn_unused arma_inline const Op<Col<eT>,op_htrans>  t() const;
+  arma_warn_unused arma_inline const Op<Col<eT>,op_htrans> ht() const;
+  arma_warn_unused arma_inline const Op<Col<eT>,op_strans> st() const;
   
-  arma_inline arma_warn_unused const Op<Col<eT>,op_strans> as_row() const;
+  arma_warn_unused arma_inline const Op<Col<eT>,op_strans> as_row() const;
   
   arma_inline       subview_col<eT> row(const uword row_num);
   arma_inline const subview_col<eT> row(const uword row_num) const;
@@ -138,15 +138,17 @@ class Col : public Mat<eT>
   
   template<typename T1> inline void shed_rows(const Base<uword, T1>& indices);
   
-                        inline void insert_rows(const uword row_num, const uword N, const bool set_to_zero = true);
+  arma_deprecated inline void insert_rows(const uword row_num, const uword N, const bool set_to_zero);
+                  inline void insert_rows(const uword row_num, const uword N);
+  
   template<typename T1> inline void insert_rows(const uword row_num, const Base<eT,T1>& X);
   
   
-  arma_inline arma_warn_unused       eT& at(const uword i);
-  arma_inline arma_warn_unused const eT& at(const uword i) const;
+  arma_warn_unused arma_inline       eT& at(const uword i);
+  arma_warn_unused arma_inline const eT& at(const uword i) const;
   
-  arma_inline arma_warn_unused       eT& at(const uword in_row, const uword in_col);
-  arma_inline arma_warn_unused const eT& at(const uword in_row, const uword in_col) const;
+  arma_warn_unused arma_inline       eT& at(const uword in_row, const uword in_col);
+  arma_warn_unused arma_inline const eT& at(const uword in_row, const uword in_col) const;
   
   
   typedef       eT*       row_iterator;
@@ -235,26 +237,26 @@ class Col<eT>::fixed : public Col<eT>
     template<typename T1, typename T2, typename eglue_type> inline Col& operator=(const eGlue<T1, T2, eglue_type>& X);
   #endif
   
-  arma_inline arma_warn_unused const Op< Col_fixed_type, op_htrans >  t() const;
-  arma_inline arma_warn_unused const Op< Col_fixed_type, op_htrans > ht() const;
-  arma_inline arma_warn_unused const Op< Col_fixed_type, op_strans > st() const;
+  arma_warn_unused arma_inline const Op< Col_fixed_type, op_htrans >  t() const;
+  arma_warn_unused arma_inline const Op< Col_fixed_type, op_htrans > ht() const;
+  arma_warn_unused arma_inline const Op< Col_fixed_type, op_strans > st() const;
   
-  arma_inline arma_warn_unused const eT& at_alt     (const uword i) const;
+  arma_warn_unused arma_inline const eT& at_alt     (const uword i) const;
   
-  arma_inline arma_warn_unused       eT& operator[] (const uword i);
-  arma_inline arma_warn_unused const eT& operator[] (const uword i) const;
-  arma_inline arma_warn_unused       eT& at         (const uword i);
-  arma_inline arma_warn_unused const eT& at         (const uword i) const;
-  arma_inline arma_warn_unused       eT& operator() (const uword i);
-  arma_inline arma_warn_unused const eT& operator() (const uword i) const;
+  arma_warn_unused arma_inline       eT& operator[] (const uword i);
+  arma_warn_unused arma_inline const eT& operator[] (const uword i) const;
+  arma_warn_unused arma_inline       eT& at         (const uword i);
+  arma_warn_unused arma_inline const eT& at         (const uword i) const;
+  arma_warn_unused arma_inline       eT& operator() (const uword i);
+  arma_warn_unused arma_inline const eT& operator() (const uword i) const;
   
-  arma_inline arma_warn_unused       eT& at         (const uword in_row, const uword in_col);
-  arma_inline arma_warn_unused const eT& at         (const uword in_row, const uword in_col) const;
-  arma_inline arma_warn_unused       eT& operator() (const uword in_row, const uword in_col);
-  arma_inline arma_warn_unused const eT& operator() (const uword in_row, const uword in_col) const;
+  arma_warn_unused arma_inline       eT& at         (const uword in_row, const uword in_col);
+  arma_warn_unused arma_inline const eT& at         (const uword in_row, const uword in_col) const;
+  arma_warn_unused arma_inline       eT& operator() (const uword in_row, const uword in_col);
+  arma_warn_unused arma_inline const eT& operator() (const uword in_row, const uword in_col) const;
   
-  arma_inline arma_warn_unused       eT* memptr();
-  arma_inline arma_warn_unused const eT* memptr() const;
+  arma_warn_unused arma_inline       eT* memptr();
+  arma_warn_unused arma_inline const eT* memptr() const;
   
   arma_hot inline const Col<eT>& fill(const eT val);
   arma_hot inline const Col<eT>& zeros();
