@@ -407,16 +407,18 @@ SpSubview<eT>::operator_equ_common(const SpBase<eT, T1>& in)
   
   const unwrap_spmat<T1> U(in.get_ref());
   
+  arma_debug_assert_same_size(n_rows, n_cols, U.M.n_rows, U.M.n_cols, "insertion into sparse submatrix");
+  
   if(U.is_alias(m))
     {
     const SpMat<eT> tmp(U.M);
     
-    return (*this).operator_equ_common(tmp);
+    spglue_merge::subview_merge(*this, tmp);
+    }
+  else
+    {
+    spglue_merge::subview_merge(*this, U.M);
     }
-  
-  arma_debug_assert_same_size(n_rows, n_cols, U.M.n_rows, U.M.n_cols, "insertion into sparse submatrix");
-  
-  spglue_merge::subview_merge(*this, U.M);
   
   return *this;
   }
@@ -939,7 +941,6 @@ SpSubview<eT>::randn()
 
 
 template<typename eT>
-arma_hot
 inline
 SpSubview_MapMat_val<eT>
 SpSubview<eT>::operator[](const uword i)
@@ -953,7 +954,6 @@ SpSubview<eT>::operator[](const uword i)
 
 
 template<typename eT>
-arma_hot
 inline
 eT
 SpSubview<eT>::operator[](const uword i) const
@@ -967,7 +967,6 @@ SpSubview<eT>::operator[](const uword i) const
 
 
 template<typename eT>
-arma_hot
 inline
 SpSubview_MapMat_val<eT>
 SpSubview<eT>::operator()(const uword i)
@@ -983,7 +982,6 @@ SpSubview<eT>::operator()(const uword i)
 
 
 template<typename eT>
-arma_hot
 inline
 eT
 SpSubview<eT>::operator()(const uword i) const
@@ -999,7 +997,6 @@ SpSubview<eT>::operator()(const uword i) const
 
 
 template<typename eT>
-arma_hot
 inline
 SpSubview_MapMat_val<eT>
 SpSubview<eT>::operator()(const uword in_row, const uword in_col)
@@ -1012,7 +1009,6 @@ SpSubview<eT>::operator()(const uword in_row, const uword in_col)
 
 
 template<typename eT>
-arma_hot
 inline
 eT
 SpSubview<eT>::operator()(const uword in_row, const uword in_col) const
@@ -1025,7 +1021,6 @@ SpSubview<eT>::operator()(const uword in_row, const uword in_col) const
 
 
 template<typename eT>
-arma_hot
 inline
 SpSubview_MapMat_val<eT>
 SpSubview<eT>::at(const uword i)
@@ -1039,7 +1034,6 @@ SpSubview<eT>::at(const uword i)
 
 
 template<typename eT>
-arma_hot
 inline
 eT
 SpSubview<eT>::at(const uword i) const
@@ -1053,7 +1047,6 @@ SpSubview<eT>::at(const uword i) const
 
 
 template<typename eT>
-arma_hot
 inline
 SpSubview_MapMat_val<eT>
 SpSubview<eT>::at(const uword in_row, const uword in_col)
@@ -1064,7 +1057,6 @@ SpSubview<eT>::at(const uword in_row, const uword in_col)
 
 
 template<typename eT>
-arma_hot
 inline
 eT
 SpSubview<eT>::at(const uword in_row, const uword in_col) const
@@ -1079,7 +1071,7 @@ inline
 bool
 SpSubview<eT>::check_overlap(const SpSubview<eT>& x) const
   {
-  const subview<eT>& t = *this;
+  const SpSubview<eT>& t = *this;
   
   if(&t.m != &x.m)
     {
@@ -1640,7 +1632,6 @@ SpSubview<eT>::is_alias(const SpMat<eT>& X) const
 
 template<typename eT>
 inline
-arma_warn_unused
 eT&
 SpSubview<eT>::insert_element(const uword in_row, const uword in_col, const eT in_val)
   {
@@ -1762,7 +1753,6 @@ SpSubview_col<eT>::operator=(const Base<eT,T1>& x)
 
 template<typename eT>
 inline
-arma_warn_unused
 const SpOp<SpSubview_col<eT>,spop_htrans>
 SpSubview_col<eT>::t() const
   {
@@ -1773,7 +1763,6 @@ SpSubview_col<eT>::t() const
 
 template<typename eT>
 inline
-arma_warn_unused
 const SpOp<SpSubview_col<eT>,spop_htrans>
 SpSubview_col<eT>::ht() const
   {
@@ -1784,7 +1773,6 @@ SpSubview_col<eT>::ht() const
 
 template<typename eT>
 inline
-arma_warn_unused
 const SpOp<SpSubview_col<eT>,spop_strans>
 SpSubview_col<eT>::st() const
   {
@@ -1871,7 +1859,6 @@ SpSubview_row<eT>::operator=(const Base<eT,T1>& x)
 
 template<typename eT>
 inline
-arma_warn_unused
 const SpOp<SpSubview_row<eT>,spop_htrans>
 SpSubview_row<eT>::t() const
   {
@@ -1882,7 +1869,6 @@ SpSubview_row<eT>::t() const
 
 template<typename eT>
 inline
-arma_warn_unused
 const SpOp<SpSubview_row<eT>,spop_htrans>
 SpSubview_row<eT>::ht() const
   {
@@ -1893,7 +1879,6 @@ SpSubview_row<eT>::ht() const
 
 template<typename eT>
 inline
-arma_warn_unused
 const SpOp<SpSubview_row<eT>,spop_strans>
 SpSubview_row<eT>::st() const
   {
