@@ -474,7 +474,6 @@ field<oT>::copy_size(const field<oT2>& x)
 //! linear element accessor (treats the field as a vector); no bounds check
 template<typename oT>
 arma_inline
-arma_warn_unused
 oT&
 field<oT>::operator[] (const uword i)
   {
@@ -486,7 +485,6 @@ field<oT>::operator[] (const uword i)
 //! linear element accessor (treats the field as a vector); no bounds check
 template<typename oT>
 arma_inline
-arma_warn_unused
 const oT&
 field<oT>::operator[] (const uword i) const
   {
@@ -498,7 +496,6 @@ field<oT>::operator[] (const uword i) const
 //! linear element accessor (treats the field as a vector); no bounds check
 template<typename oT>
 arma_inline
-arma_warn_unused
 oT&
 field<oT>::at(const uword i)
   {
@@ -510,7 +507,6 @@ field<oT>::at(const uword i)
 //! linear element accessor (treats the field as a vector); no bounds check
 template<typename oT>
 arma_inline
-arma_warn_unused
 const oT&
 field<oT>::at(const uword i) const
   {
@@ -522,7 +518,6 @@ field<oT>::at(const uword i) const
 //! linear element accessor (treats the field as a vector); bounds checking not done when ARMA_NO_DEBUG is defined
 template<typename oT>
 arma_inline
-arma_warn_unused
 oT&
 field<oT>::operator() (const uword i)
   {
@@ -536,7 +531,6 @@ field<oT>::operator() (const uword i)
 //! linear element accessor (treats the field as a vector); bounds checking not done when ARMA_NO_DEBUG is defined
 template<typename oT>
 arma_inline
-arma_warn_unused
 const oT&
 field<oT>::operator() (const uword i) const
   {
@@ -550,7 +544,6 @@ field<oT>::operator() (const uword i) const
 //! element accessor; bounds checking not done when ARMA_NO_DEBUG is defined
 template<typename oT>
 arma_inline
-arma_warn_unused
 oT&
 field<oT>::operator() (const uword in_row, const uword in_col)
   {
@@ -564,7 +557,6 @@ field<oT>::operator() (const uword in_row, const uword in_col)
 //! element accessor; bounds checking not done when ARMA_NO_DEBUG is defined
 template<typename oT>
 arma_inline
-arma_warn_unused
 const oT&
 field<oT>::operator() (const uword in_row, const uword in_col) const
   {
@@ -578,7 +570,6 @@ field<oT>::operator() (const uword in_row, const uword in_col) const
 //! element accessor; bounds checking not done when ARMA_NO_DEBUG is defined
 template<typename oT>
 arma_inline
-arma_warn_unused
 oT&
 field<oT>::operator() (const uword in_row, const uword in_col, const uword in_slice)
   {
@@ -592,7 +583,6 @@ field<oT>::operator() (const uword in_row, const uword in_col, const uword in_sl
 //! element accessor; bounds checking not done when ARMA_NO_DEBUG is defined
 template<typename oT>
 arma_inline
-arma_warn_unused
 const oT&
 field<oT>::operator() (const uword in_row, const uword in_col, const uword in_slice) const
   {
@@ -608,8 +598,7 @@ field<oT>::operator() (const uword in_row, const uword in_col, const uword in_sl
   //! element accessor; no bounds check
   template<typename oT>
   arma_inline
-  arma_warn_unused
-  oT&
+    oT&
   field<oT>::operator[] (const uword in_row, const uword in_col)
     {
     return (*mem[in_row + in_col*n_rows]);
@@ -620,8 +609,7 @@ field<oT>::operator() (const uword in_row, const uword in_col, const uword in_sl
   //! element accessor; no bounds check
   template<typename oT>
   arma_inline
-  arma_warn_unused
-  const oT&
+    const oT&
   field<oT>::operator[] (const uword in_row, const uword in_col) const
     {
     return (*mem[in_row + in_col*n_rows]);
@@ -634,7 +622,6 @@ field<oT>::operator() (const uword in_row, const uword in_col, const uword in_sl
 //! element accessor; no bounds check
 template<typename oT>
 arma_inline
-arma_warn_unused
 oT&
 field<oT>::at(const uword in_row, const uword in_col)
   {
@@ -646,7 +633,6 @@ field<oT>::at(const uword in_row, const uword in_col)
 //! element accessor; no bounds check
 template<typename oT>
 arma_inline
-arma_warn_unused
 const oT&
 field<oT>::at(const uword in_row, const uword in_col) const
   {
@@ -660,8 +646,7 @@ field<oT>::at(const uword in_row, const uword in_col) const
   //! element accessor; no bounds check
   template<typename oT>
   arma_inline
-  arma_warn_unused
-  oT&
+    oT&
   field<oT>::operator[] (const uword in_row, const uword in_col, const uword in_slice)
     {
     return (*mem[in_row + in_col*n_rows + in_slice*(n_rows*n_cols)]);
@@ -672,8 +657,7 @@ field<oT>::at(const uword in_row, const uword in_col) const
   //! element accessor; no bounds check
   template<typename oT>
   arma_inline
-  arma_warn_unused
-  const oT&
+    const oT&
   field<oT>::operator[] (const uword in_row, const uword in_col, const uword in_slice) const
     {
     return (*mem[in_row + in_col*n_rows + in_slice*(n_rows*n_cols)]);
@@ -686,7 +670,6 @@ field<oT>::at(const uword in_row, const uword in_col) const
 //! element accessor; no bounds check
 template<typename oT>
 arma_inline
-arma_warn_unused
 oT&
 field<oT>::at(const uword in_row, const uword in_col, const uword in_slice)
   {
@@ -698,7 +681,6 @@ field<oT>::at(const uword in_row, const uword in_col, const uword in_slice)
 //! element accessor; no bounds check
 template<typename oT>
 arma_inline
-arma_warn_unused
 const oT&
 field<oT>::at(const uword in_row, const uword in_col, const uword in_slice) const
   {
@@ -709,7 +691,6 @@ field<oT>::at(const uword in_row, const uword in_col, const uword in_slice) cons
 
 template<typename oT>
 arma_inline
-arma_warn_unused
 oT&
 field<oT>::front()
   {
@@ -722,7 +703,6 @@ field<oT>::front()
 
 template<typename oT>
 arma_inline
-arma_warn_unused
 const oT&
 field<oT>::front() const
   {
@@ -735,7 +715,6 @@ field<oT>::front() const
 
 template<typename oT>
 arma_inline
-arma_warn_unused
 oT&
 field<oT>::back()
   {
@@ -748,7 +727,6 @@ field<oT>::back()
 
 template<typename oT>
 arma_inline
-arma_warn_unused
 const oT&
 field<oT>::back() const
   {
@@ -760,7 +738,6 @@ field<oT>::back() const
 
 
 template<typename oT>
-arma_deprecated
 inline
 field_injector< field<oT> >
 field<oT>::operator<<(const oT& val)
@@ -771,7 +748,6 @@ field<oT>::operator<<(const oT& val)
 
 
 template<typename oT>
-arma_deprecated
 inline
 field_injector< field<oT> >
 field<oT>::operator<<(const injector_end_of_row<>& x)
@@ -1485,7 +1461,6 @@ field<oT>::operator()(const uword in_row1, const uword in_col1, const uword in_s
 //! has been defined.
 
 template<typename oT>
-arma_cold
 inline
 void
 field<oT>::print(const std::string extra_text) const
@@ -1516,7 +1491,6 @@ field<oT>::print(const std::string extra_text) const
 //! has been defined.
 
 template<typename oT>
-arma_cold
 inline
 void
 field<oT>::print(std::ostream& user_stream, const std::string extra_text) const
@@ -1623,7 +1597,6 @@ field<oT>::is_empty() const
 //! returns true if the given index is currently in range
 template<typename oT>
 arma_inline
-arma_warn_unused
 bool
 field<oT>::in_range(const uword i) const
   {
@@ -1635,7 +1608,6 @@ field<oT>::in_range(const uword i) const
 //! returns true if the given start and end indices are currently in range
 template<typename oT>
 arma_inline
-arma_warn_unused
 bool
 field<oT>::in_range(const span& x) const
   {
@@ -1659,7 +1631,6 @@ field<oT>::in_range(const span& x) const
 //! returns true if the given location is currently in range
 template<typename oT>
 arma_inline
-arma_warn_unused
 bool
 field<oT>::in_range(const uword in_row, const uword in_col) const
   {
@@ -1670,7 +1641,6 @@ field<oT>::in_range(const uword in_row, const uword in_col) const
 
 template<typename oT>
 arma_inline
-arma_warn_unused
 bool
 field<oT>::in_range(const span& row_span, const uword in_col) const
   {
@@ -1693,7 +1663,6 @@ field<oT>::in_range(const span& row_span, const uword in_col) const
 
 template<typename oT>
 arma_inline
-arma_warn_unused
 bool
 field<oT>::in_range(const uword in_row, const span& col_span) const
   {
@@ -1716,7 +1685,6 @@ field<oT>::in_range(const uword in_row, const span& col_span) const
 
 template<typename oT>
 arma_inline
-arma_warn_unused
 bool
 field<oT>::in_range(const span& row_span, const span& col_span) const
   {
@@ -1738,7 +1706,6 @@ field<oT>::in_range(const span& row_span, const span& col_span) const
 
 template<typename oT>
 arma_inline
-arma_warn_unused
 bool
 field<oT>::in_range(const uword in_row, const uword in_col, const SizeMat& s) const
   {
@@ -1759,7 +1726,6 @@ field<oT>::in_range(const uword in_row, const uword in_col, const SizeMat& s) co
 
 template<typename oT>
 arma_inline
-arma_warn_unused
 bool
 field<oT>::in_range(const uword in_row, const uword in_col, const uword in_slice) const
   {
@@ -1770,7 +1736,6 @@ field<oT>::in_range(const uword in_row, const uword in_col, const uword in_slice
 
 template<typename oT>
 arma_inline
-arma_warn_unused
 bool
 field<oT>::in_range(const span& row_span, const span& col_span, const span& slice_span) const
   {
@@ -1796,7 +1761,6 @@ field<oT>::in_range(const span& row_span, const span& col_span, const span& slic
 
 template<typename oT>
 arma_inline
-arma_warn_unused
 bool
 field<oT>::in_range(const uword in_row, const uword in_col, const uword in_slice, const SizeCube& s) const
   {
@@ -1818,7 +1782,6 @@ field<oT>::in_range(const uword in_row, const uword in_col, const uword in_slice
 
 template<typename oT>
 inline
-arma_cold
 bool
 field<oT>::save(const std::string name, const file_type type) const
   {
@@ -1847,7 +1810,6 @@ field<oT>::save(const std::string name, const file_type type) const
 
 template<typename oT>
 inline
-arma_cold
 bool
 field<oT>::save(std::ostream& os, const file_type type) const
   {
@@ -1876,7 +1838,6 @@ field<oT>::save(std::ostream& os, const file_type type) const
 
 template<typename oT>
 inline
-arma_cold
 bool
 field<oT>::load(const std::string name, const file_type type)
   {
@@ -1907,7 +1868,6 @@ field<oT>::load(const std::string name, const file_type type)
 
 template<typename oT>
 inline
-arma_cold
 bool
 field<oT>::load(std::istream& is, const file_type type)
   {
@@ -1936,7 +1896,6 @@ field<oT>::load(std::istream& is, const file_type type)
 
 
 template<typename oT>
-arma_deprecated
 inline
 bool
 field<oT>::quiet_save(const std::string name, const file_type type) const
@@ -1949,7 +1908,6 @@ field<oT>::quiet_save(const std::string name, const file_type type) const
 
 
 template<typename oT>
-arma_deprecated
 inline
 bool
 field<oT>::quiet_save(std::ostream& os, const file_type type) const
@@ -1962,7 +1920,6 @@ field<oT>::quiet_save(std::ostream& os, const file_type type) const
 
 
 template<typename oT>
-arma_deprecated
 inline
 bool
 field<oT>::quiet_load(const std::string name, const file_type type)
@@ -1975,7 +1932,6 @@ field<oT>::quiet_load(const std::string name, const file_type type)
 
 
 template<typename oT>
-arma_deprecated
 inline
 bool
 field<oT>::quiet_load(std::istream& is, const file_type type)
