@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: Apache-2.0
+// 
 // Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
@@ -200,6 +202,19 @@ struct is_subview_col< const subview_col<eT> >
   { static constexpr bool value = true; };
 
 
+template<typename T>
+struct is_subview_cols
+  { static constexpr bool value = false; };
+
+template<typename eT>
+struct is_subview_cols< subview_cols<eT> >
+  { static constexpr bool value = true; };
+
+template<typename eT>
+struct is_subview_cols< const subview_cols<eT> >
+  { static constexpr bool value = true; };
+
+
 template<typename T>
 struct is_subview_elem1
   { static constexpr bool value = false; };
@@ -542,6 +557,7 @@ struct is_arma_type2
   || is_subview<T1>::value
   || is_subview_row<T1>::value
   || is_subview_col<T1>::value
+  || is_subview_cols<T1>::value
   || is_subview_elem1<T1>::value
   || is_subview_elem2<T1>::value
   ;
@@ -1191,39 +1207,58 @@ struct is_outer_product< Glue<T1,T2,glue_times> >
 
 
 template<typename T1>
-struct has_op_inv
+struct has_op_inv_any
   { static constexpr bool value = false; };
 
 template<typename T1>
-struct has_op_inv< Op<T1,op_inv> >
+struct has_op_inv_any< Op<T1,op_inv_gen_full> >
   { static constexpr bool value = true;  };
 
-template<typename T1, typename T2>
-struct has_op_inv< Glue<Op<T1,op_inv>, T2, glue_times> >
-  { static constexpr bool value = true;  };
-
-template<typename T1, typename T2>
-struct has_op_inv< Glue<T1, Op<T2,op_inv>, glue_times> >
-  { static constexpr bool value = true;  };
-
-
-
 template<typename T1>
-struct has_op_inv_sympd
-  { static constexpr bool value = false; };
+struct has_op_inv_any< Op<T1,op_inv_spd_full> >
+  { static constexpr bool value = true;  };
 
 template<typename T1>
-struct has_op_inv_sympd< Op<T1,op_inv_sympd> >
+struct has_op_inv_any< Op<T1,op_inv_gen_default> >
+  { static constexpr bool value = true;  };
+
+template<typename T1>
+struct has_op_inv_any< Op<T1,op_inv_spd_default> >
   { static constexpr bool value = true;  };
 
 template<typename T1, typename T2>
-struct has_op_inv_sympd< Glue<Op<T1,op_inv_sympd>, T2, glue_times> >
+struct has_op_inv_any< Glue<Op<T1,op_inv_gen_full>, T2, glue_times> >
   { static constexpr bool value = true;  };
 
 template<typename T1, typename T2>
-struct has_op_inv_sympd< Glue<T1, Op<T2,op_inv_sympd>, glue_times> >
+struct has_op_inv_any< Glue<Op<T1,op_inv_spd_full>, T2, glue_times> >
   { static constexpr bool value = true;  };
 
+template<typename T1, typename T2>
+struct has_op_inv_any< Glue<Op<T1,op_inv_gen_default>, T2, glue_times> >
+  { static constexpr bool value = true;  };
+
+template<typename T1, typename T2>
+struct has_op_inv_any< Glue<Op<T1,op_inv_spd_default>, T2, glue_times> >
+  { static constexpr bool value = true;  };
+
+template<typename T1, typename T2>
+struct has_op_inv_any< Glue<T1, Op<T2,op_inv_gen_full>, glue_times> >
+  { static constexpr bool value = true;  };
+
+template<typename T1, typename T2>
+struct has_op_inv_any< Glue<T1, Op<T2,op_inv_spd_full>, glue_times> >
+  { static constexpr bool value = true;  };
+
+template<typename T1, typename T2>
+struct has_op_inv_any< Glue<T1, Op<T2,op_inv_gen_default>, glue_times> >
+  { static constexpr bool value = true;  };
+
+template<typename T1, typename T2>
+struct has_op_inv_any< Glue<T1, Op<T2,op_inv_spd_default>, glue_times> >
+  { static constexpr bool value = true;  };
+
+
 
 
 template<typename T>
